/*
 *	PROGRAM:	JRD Access Method
 *	MODULE:		kanji_proto.h
 *	DESCRIPTION:	Prototype header file for kanji.cpp
 *
 * The contents of this file are subject to the Interbase Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy
 * of the License at http://www.Inprise.com/IPL.html
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code was created by Inprise Corporation
 * and its predecessors. Portions created by Inprise Corporation are
 * Copyright (C) Inprise Corporation.
 *
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 */

#ifndef JRD_KANJI_PROTO_H
#define JRD_KANJI_PROTO_H

USHORT KANJI_check_euc(const UCHAR*, USHORT);
USHORT KANJI_check_sjis(const UCHAR*, USHORT);
USHORT KANJI_euc2sjis(const UCHAR*, USHORT, UCHAR*, USHORT, USHORT*);
USHORT KANJI_euc_byte2short(const UCHAR*, USHORT*, USHORT);
USHORT KANJI_euc_len(const UCHAR*, USHORT, USHORT*);
USHORT KANJI_sjis2euc(const UCHAR*, USHORT, UCHAR*, USHORT, USHORT*);
USHORT KANJI_sjis_byte2short(const UCHAR*, USHORT*, USHORT);
USHORT KANJI_sjis2euc5(const UCHAR*, USHORT, UCHAR*, USHORT, USHORT*,
							  USHORT*, USHORT*);
USHORT KANJI_sjis_len(const UCHAR*, USHORT, USHORT*);

#endif // JRD_KANJI_PROTO_H

